==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/HeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
var HeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HeaderDescriptionMetadata, _super);
    function HeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeaderDescriptionMetadata.b = function (a) {
        if (HeaderDescriptionMetadata.a == null) {
            HeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeaderDescriptionMetadata.c(HeaderDescriptionMetadata.a);
        }
        if (a.k(HeaderDescriptionMetadata.a)) {
            return;
        }
        a.ab(HeaderDescriptionMetadata.a);
    };
    HeaderDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("SortIndicatorColor", "Brush");
        a.item("ActualSortIndicatorColor", "Brush");
        a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("ActualSortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("ActualSortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
    };
    HeaderDescriptionMetadata.d = function (a) {
        HeaderDescriptionMetadata.b(a);
        a.ac("Header", HeaderDescriptionMetadata.a);
    };
    HeaderDescriptionMetadata.$t = markType(HeaderDescriptionMetadata, 'HeaderDescriptionMetadata');
    HeaderDescriptionMetadata.a = null;
    return HeaderDescriptionMetadata;
}(Base));
export { HeaderDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/HeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
var HeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HeaderDescriptionMetadata, _super);
    function HeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeaderDescriptionMetadata.b = function (a) {
        if (HeaderDescriptionMetadata.a == null) {
            HeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeaderDescriptionMetadata.c(HeaderDescriptionMetadata.a);
        }
        if (a.k(HeaderDescriptionMetadata.a)) {
            return;
        }
        a.ac(HeaderDescriptionMetadata.a);
    };
    HeaderDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("SortIndicatorColor", "Brush");
        a.item("ActualSortIndicatorColor", "Brush");
        a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("ActualSortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("ActualSortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
    };
    HeaderDescriptionMetadata.d = function (a) {
        HeaderDescriptionMetadata.b(a);
        a.ad("Header", HeaderDescriptionMetadata.a);
    };
    HeaderDescriptionMetadata.$t = markType(HeaderDescriptionMetadata, 'HeaderDescriptionMetadata');
    HeaderDescriptionMetadata.a = null;
    return HeaderDescriptionMetadata;
}(Base));
export { HeaderDescriptionMetadata };
